#!/usr/bin/perl -w
#
# This script measures LanguageTool startup time
# for various versions and languages It:
# - downloads LanguageToo*.zip files from
#   https://languagetool.org/download/ and caches them
#   to avoid re-downloading again when running
#   multiple times.
# - unzip LanguageToo*.zip 
# - measure the time to run LanguageTool with an empty input
#   in various languages
# - format measurements in a table
#
# Author: Dominique Pelle
use Time::HiRes qw(time);

my @versions = ('4.1', '4.0',
                '3.9', '3.8', '3.7', '3.6', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0',
                '2.9', '2.8', '2.7', '2.6', '2.5', '2.4', '2.3', '2.2', '2.1');
my @languages = ('br', 'ca', 'fr', 'de-DE', 'en-US', 'it', 'nl', 'eo', 'es', 'pl', 'pt-PT', 'ru');
my %startup_time;

foreach my $version (@versions) {
  my $lt="LanguageTool-$version";
  my $zip_file="$lt.zip";

  unless (-e "$zip_file") {
    print "Downloading $zip_file\n";
    `wget https://languagetool.org/download/$zip_file`;
  }
  unless (-e "$lt/languagetool-commandline.jar") {
    print "Unzipping $zip_file\n";
    `unzip -o $zip_file`;
  }

  foreach $lang (@languages) {
    print "Measuring startup time of $lt in language $lang\n";
    my $start = time;
    `echo | java -jar \"$lt/languagetool-commandline.jar\" -c utf-8 -l $lang -`;
    my $duration = time - $start;

    $startup_time{$version}{$lang} = $duration;
  }
}

print "LanguageTool startup time in seconds\n\n";
print "version  ";
foreach $lang (@languages) { printf "%-5s ", $lang; }
print "\n-------  ";
foreach $lang (@languages) { printf "----- "; }
print "\n";
foreach my $version (@versions) {
  printf "%-7s  ", $version;
  foreach $lang (@languages) {
    printf "%-5.2f ", $startup_time{$version}{$lang};
  }
  print "\n";
}
